#!/bin/bash

# Script to install OpenH264
# SPDX-License-Identifier: GPL-2.0-or-later

# Packages to install
OPENH264_PACKAGES=""

##
## Automatically install openh264 for Firefox if it's not present.
##
## To disable, set NO_INSTALL_MOZ_OPENH264=1 in /etc/sysconfig/fedora-firstboot.
##

if [ -z "$NO_INSTALL_MOZ_OPENH264" ]; then
    OPENH264_PACKAGES="mozilla-openh264 $OPENH264_PACKAGES"
fi

##
## Automatically install openh264 for GStreamer if it's not present.
##
## To disable, set NO_INSTALL_GST_OPENH264=1 in /etc/sysconfig/fedora-firstboot.
##
if [ -z "$NO_INSTALL_GST_OPENH264" ]; then
    OPENH264_PACKAGES="gstreamer1-plugin-openh264 $OPENH264_PACKAGES"
fi


if [ -n "$NO_INSTALL_GST_OPENH264" ] && [ -n "$NO_INSTALL_MOZ_OPENH264" ]; then
    NO_INSTALL_OPENH264=1
fi

# Trim package set variable
OPENH264_PACKAGES=$(echo "${OPENH264_PACKAGES}" | xargs)

# Install openh264 packages
if [ -z "$NO_INSTALL_OPENH264" ] && [ -x "/usr/bin/rpm" ]; then
    if ! rpm --quiet --query "${OPENH264_PACKAGES}"; then
        (
            # Check the OS to ensure we're not RHEL-like
            source /etc/os-release
            if [[ "$ID" != "rhel" ]] && [[ "$ID_LIKE" != *"rhel"* ]]; then
                if [ ! -e "/run/ostree-booted" ] && [ -x "/usr/bin/pkcon" ]; then
                       pkcon --noninteractive install ${OPENH264_PACKAGES}
                fi
                if [ -e "/run/ostree-booted" ] && [ -x "/usr/bin/rpm-ostree" ]; then
                       rpm-ostree install --assumeyes --allow-inactive --idempotent --apply-live ${OPENH264_PACKAGES}
                fi
            fi
        )
    fi
fi


